Installation - JQpy 1.0.0 documentation

# Installation

1. Install JQ binary for your platform and include it to `PATH` environment variable (should be included by default).

   JQ download page

   Quick commands:

   - Windows + winget: `winget install jqlang.jq`

   - Windows + scoop: `scoop install jq`

   - Windows + choco: `choco install jq`

   - Windows + exe

   - Ubuntu: `sudo apt-get install jq`

   - Arch: `sudo pacman -S jq`

   - macOS + brew: `brew install jq`

2. Install JQpy python binding via pip or your favourite python package manager:

   `pip install jqpy`

Back to top